@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2011 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2012 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -83,6 +83,10 @@ extern inline int wcscasecmp(const wchar_t* s1, const wchar_t* s2);
 #define LOG_SPECIAL_MARKER TEXT("#!#WrApPeRsPeCiAl#!#")
 #endif
 
+/* Default log formats */
+#define LOG_FORMAT_LOGFILE_DEFAULT TEXT("LPTM")
+#define LOG_FORMAT_CONSOLE_DEFAULT TEXT("PM")
+
 /* * * Log level constants * * */
 
 /* No logging at all. */
